==> zither-1.1.13.tar.gz: zither_prj/apollon/config_newedit.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
// window.onload=WinCls();
//-->";
echo "</SCRIPT>";


$CNAME = $_GET["CNAME"];
$CIP = $_GET["CIP"];


if(0 != strlen($CNAME)){

$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

$result = pg_query($conn, "select * from config where c_name='$CNAME'");
if(!$result){
   print("bud query\n");
   exit;
   }

$num = pg_num_rows($result);
if($num <= 0){
   print("no data\n");
   exit;
   }

$s = 0;
while($s < $num){

   $C_NAME = rtrim(pg_fetch_Result($result, $s, c_name));
   $C_INFO = rtrim(pg_fetch_Result($result, $s, c_info));
   $SOCK_IPADDR = rtrim(pg_fetch_Result($result, $s, sock_ipaddr));
   $SOCK2_IPADDR = rtrim(pg_fetch_Result($result, $s, sock2_ipaddr));
   $SOCK_PORT = rtrim(pg_fetch_Result($result, $s, sock_port));
   $SOCK2_PORT = rtrim(pg_fetch_Result($result, $s, sock2_port));
   $BAT_FILE = rtrim(pg_fetch_Result($result, $s, bat_file));
   $BAT2_FILE = rtrim(pg_fetch_Result($result, $s, bat2_file));
   $COMMAND_PATH = rtrim(pg_fetch_Result($result, $s, command_path));
   $BAT_INT = rtrim(pg_fetch_Result($result, $s, bat_int));
   $BAT2_INT = rtrim(pg_fetch_Result($result, $s, bat2_int));
   $LIFE_INT = rtrim(pg_fetch_Result($result, $s, life_int));
   $LIFE_LOS = rtrim(pg_fetch_Result($result, $s, life_los));
   $MAIL_CC = rtrim(pg_fetch_Result($result, $s, mail_cc));
   $UPDATE_COM = rtrim(pg_fetch_Result($result, $s, update_com));

   $s++;
   }

pg_free_result($result);
pg_Close($conn);

}


print("</head>\n");
print("<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>\n");

print("<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=100%>\n");
print("<tr><td align=left><font color='ffffff'><b>ƻ -> Խ</b></font></td></tr>\n");
print("</table>\n");

echo "<pre>";
print($font_size);
print($version_name);
print(date("Y m d g i s A"));
print("\n");
print("ƻ륯饤Ȥεưե򿷵Ǥޤ\n");
print("Ʊ˸ܤȤʤƻܤɲýޤ\n");
print("ƻƤϤ٤ƥƥȥ⡼ɤȤʤޤ\n");

echo "\n";
echo "<FORM METHOD=GET ACTION='config_upnew.php' target=config_upnew>";

echo "<TABLE cellspacing=0 cellpadding=3 nowrap border=1 Bordercolor='$my_bocolor' nowrap border=0 WIDTH='790' height='8%'BGCOLOR='#e6e8fa'>";


// echo "<TABLE  cellspacing=0 cellpadding=3 nowrap border=0 Bordercolor='$my_bocolor' nowrap border=0  WIDTH='90%' height='8%'BGCOLOR='#e6e8fa'>";

echo "<tr><td>";
echo "ƻ륯饤ȤΥۥ̾ \n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=C_NAME size='24' value=''>";
   }
else{
   echo "<INPUT type='text' NAME=C_NAME size='24' value='$C_NAME'>";
   }
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ƻ륯饤ȤIPɥ쥹\n";
echo "</td><td>";
echo "<INPUT type='text' NAME=CIP size='24' value='$CIP'>";
echo "</td></tr>";

echo "<tr><td>";
echo "ƻ륯饤Ȥξ\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=C_INFO size='100' value='եޥåȤ'>";
   }
else{
   echo "<INPUT type='text' NAME=C_INFO size='100' value='$C_INFO'>";
   }
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ƻ륵ФIP\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=SOCK_IPADDR size='24' value='$my_server_ip'>";
   }
else{
   echo "<INPUT type='text' NAME=SOCK_IPADDR size='24' value='$SOCK_IPADDR'>";
   }
echo "</td></tr>";

echo "<tr><td>";
echo "ƻ륵ФΥݡȭ\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=SOCK_PORT size='6' value='9988'>";
   }
else{
   echo "<INPUT type='text' NAME=SOCK_PORT size='6' value='$SOCK_PORT'>";
   }
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ƻ륵ФIP\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=SOCK2_IPADDR size='24' value='$my_server_ip'>";
   }
else{
   echo "<INPUT type='text' NAME=SOCK2_IPADDR size='24' value='$SOCK2_IPADDR'>";
   }
echo "</td></tr>";

echo "<tr><td>";
echo "ƻ륵ФΥݡȭ\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=SOCK2_PORT size='6' value='9988'>";
   }
else{
   echo "<INPUT type='text' NAME=SOCK2_PORT size='6' value='$SOCK2_PORT'>";
   }
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ե\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=BAT_FILE size='80' value='/usr/local/zither/tmp/sitar.bat'>";
   }
else{
   echo "<INPUT type='text' NAME=BAT_FILE size='80' value='$BAT_FILE'>";
   }
echo "</td></tr>";

echo "<tr><td>";
echo "ե\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=BAT2_FILE size='80' value='/usr/local/zither/tmp/sitar.list'>";
   }
else{
   echo "<INPUT type='text' NAME=BAT2_FILE size='80' value='$BAT2_FILE'>";
   }
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ޥɤ֤\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=COMMAND_PATH size='80' value='/usr/local/zither/sample_bin'>";
   }
else{
   echo "<INPUT type='text' NAME=COMMAND_PATH size='80' value='$COMMAND_PATH'>";
   }
echo "</td></tr>";

echo "<tr><td>";
echo "ƻ륤󥿡Х뭡\n";
echo "</td><td>";
echo "<select size=1 name=BAT_INT>";
if(0 == strlen($CNAME)){ 
   echo "<option value=$BAT_INT selected>$BAT_INT";
   }
else{
   echo "<option value=60 selected>60";
   }
echo "<option value=60>60";
echo "<option value=30>30";
echo "<option value=60>60";
echo "<option value=90>90";
echo "<option value=120>120";
echo "<option value=150>150";
echo "<option value=180>180";
echo "<option value=210>210";
echo "<option value=240>240";
echo "</select>";
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ƻ륤󥿡Х\n";
echo "</td><td>";
echo "<select size=1 name=BAT2_INT>";
if(0 == strlen($CNAME)){ 
   echo "<option value=$BAT2_INT selected>$BAT2_INT";
   }
else{
   echo "<option value=60 selected>60";
   }
echo "<option value=30>30";
echo "<option value=60>60";
echo "<option value=90>90";
echo "<option value=120>120";
echo "<option value=150>150";
echo "<option value=180>180";
echo "<option value=210>210";
echo "<option value=240>240";
echo "</select>";
echo "</td></tr>";

echo "<tr><td>";
echo "̴ƻ륤󥿡Х\n";
echo "</td><td>";
echo "<select size=1 name=LIFE_INT>";
if(0 == strlen($CNAME)){ 
   echo "<option value=$LIFE_INT selected>$LIFE_INT";
   }
else{
   echo "<option value=20 selected>20";
   }
echo "<option value=10>10";
echo "<option value=15>15";
echo "<option value=20>20";
echo "<option value=25>25";
echo "<option value=30>30";
echo "</select>";
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "̴ƻ\n";
echo "</td><td>";
echo "<select size=1 name=LIFE_LOS>";
if(0 == strlen($CNAME)){ 
   echo "<option value=$LIFE_LOS selected>$LIFE_LOS";
   }
else{
   echo "<option value=5 selected>5";
   }
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "<option value=6>6";
echo "<option value=7>7";
echo "<option value=8>8";
echo "</select>";
echo "</td></tr>";

echo "<tr><td>";
echo "ᤤCC\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=MAIL_CC size='60' value='$MAIL_CC'>";
   }
else{
   echo "<INPUT type='text' NAME=MAIL_CC size='60' value=''>";
   }
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "UPDATEѥޥɤΥѥ";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=UPDATE_COM size='100' value='/usr/local/zither/bin/get_sitar.sh'>";
   }
else{
   echo "<INPUT type='text' NAME=UPDATE_COM size='100' value='$UPDATE_COM'>";
   }
echo "</td></tr>";

echo "<tr><td>";
echo "ܴƻɲ";
echo "</td><td>";
echo "<INPUT type='checkbox' value='ON' NAME=COM_MONITOR checked>";
echo "ʥ饤̾_defaultˤƺޤ";
echo "</td></tr>";

echo"</table>";

echo "\n";
echo "<font color=red>";
print("ǡ١ƤȿǤƱzitherФˤȿǤޤ\n");
print("ФȿǤ줿ϡưǴƻ륯饤ȤƵưޤΤդƤ\n");
echo "</font>";
echo "<input type=submit value='ƻ륯饤Ȥκ'>";
echo "</form>";




print("</font>");

?>

</pre>
</body>
</html>

==> zither-1.1.15.tar.gz: zither_prj/apollon/config_newedit.php <==
<?php
require("./total.inc");

session_start();
require("./ninsyou.inc");
if(0 > ninsyou_check(5)){
   exit;
   }


echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
echo "<HTML>";
echo "<HEAD>";
echo "<META name='GENERATOR' content='AmBuilder'>";
echo "<META http-equiv='Content-Type' content='text/html; charset=euc-jp'>";
	echo "<title>zither monitorring save info</title>";

echo "<SCRIPT LANGUAGE='JavaScript'>";
echo "<!--

function WinCls(){
        window.close()
                       }
// window.onload=WinCls();
//-->";
echo "</SCRIPT>";


$CNAME = enco($_GET["CNAME"]);
$CIP = enco($_GET["CIP"]);


if(0 != strlen($CNAME)){

$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
if(!$conn){
   echo "not connection!<br>";
   exit;
   }

$result = pg_query($conn, "select * from config where c_name='$CNAME'");
if(!$result){
   print("bud query\n");
   exit;
   }

$num = pg_num_rows($result);
if($num <= 0){
   print("no data\n");
   exit;
   }

$s = 0;
while($s < $num){

   $C_NAME = enco_rtrim(pg_fetch_Result($result, $s, c_name));
   $C_INFO = enco_rtrim(pg_fetch_Result($result, $s, c_info));
   $SOCK_IPADDR = enco_rtrim(pg_fetch_Result($result, $s, sock_ipaddr));
   $SOCK2_IPADDR = enco_rtrim(pg_fetch_Result($result, $s, sock2_ipaddr));
   $SOCK_PORT = enco_rtrim(pg_fetch_Result($result, $s, sock_port));
   $SOCK2_PORT = enco_rtrim(pg_fetch_Result($result, $s, sock2_port));
   $BAT_FILE = enco_rtrim(pg_fetch_Result($result, $s, bat_file));
   $BAT2_FILE = enco_rtrim(pg_fetch_Result($result, $s, bat2_file));
   $COMMAND_PATH = enco_rtrim(pg_fetch_Result($result, $s, command_path));
   $BAT_INT = enco_rtrim(pg_fetch_Result($result, $s, bat_int));
   $BAT2_INT = enco_rtrim(pg_fetch_Result($result, $s, bat2_int));
   $LIFE_INT = enco_rtrim(pg_fetch_Result($result, $s, life_int));
   $LIFE_LOS = enco_rtrim(pg_fetch_Result($result, $s, life_los));
   $MAIL_CC = enco_rtrim(pg_fetch_Result($result, $s, mail_cc));
   $UPDATE_COM = enco_rtrim(pg_fetch_Result($result, $s, update_com));

   $s++;
   }

pg_free_result($result);
pg_Close($conn);

}


print("</head>\n");
print("<body alink='#ff0000' bgcolor='$my_bgcolor' link='#0000ff' text='#000000' vlink='#000080'>\n");

print("<TABLE border='0' bgcolor='FFA500' cellspacing='3' cellpadding='0' width=100%>\n");
print("<tr><td align=left><font color='ffffff'><b>ƻ -> Խ</b></font></td></tr>\n");
print("</table>\n");

echo "<pre>";
print($font_size);
print($version_name);
print(date("Y m d g i s A"));
print("\n");
print("ƻ륯饤Ȥεưե򿷵Ǥޤ\n");
print("Ʊ˸ܤȤʤƻܤɲýޤ\n");
print("ƻƤϤ٤ƥƥȥ⡼ɤȤʤޤ\n");

echo "\n";
echo "<FORM METHOD=GET ACTION='config_upnew.php' target=config_upnew>";

echo "<TABLE cellspacing=0 cellpadding=3 nowrap border=1 Bordercolor='$my_bocolor' nowrap border=0 WIDTH='790' height='8%'BGCOLOR='#e6e8fa'>";


// echo "<TABLE  cellspacing=0 cellpadding=3 nowrap border=0 Bordercolor='$my_bocolor' nowrap border=0  WIDTH='90%' height='8%'BGCOLOR='#e6e8fa'>";

echo "<tr><td>";
echo "ƻ륯饤ȤΥۥ̾ \n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=C_NAME size='24' value=''>";
   }
else{
   echo "<INPUT type='text' NAME=C_NAME size='24' value='$C_NAME'>";
   }
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ƻ륯饤ȤIPɥ쥹\n";
echo "</td><td>";
echo "<INPUT type='text' NAME=CIP size='24' value='$CIP'>";
echo "</td></tr>";

echo "<tr><td>";
echo "ƻ륯饤Ȥξ\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=C_INFO size='100' value='եޥåȤ'>";
   }
else{
   echo "<INPUT type='text' NAME=C_INFO size='100' value='$C_INFO'>";
   }
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ƻ륵ФIP\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=SOCK_IPADDR size='24' value='$my_server_ip'>";
   }
else{
   echo "<INPUT type='text' NAME=SOCK_IPADDR size='24' value='$SOCK_IPADDR'>";
   }
echo "</td></tr>";

echo "<tr><td>";
echo "ƻ륵ФΥݡȭ\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=SOCK_PORT size='6' value='9988'>";
   }
else{
   echo "<INPUT type='text' NAME=SOCK_PORT size='6' value='$SOCK_PORT'>";
   }
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ƻ륵ФIP\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=SOCK2_IPADDR size='24' value='$my_server_ip'>";
   }
else{
   echo "<INPUT type='text' NAME=SOCK2_IPADDR size='24' value='$SOCK2_IPADDR'>";
   }
echo "</td></tr>";

echo "<tr><td>";
echo "ƻ륵ФΥݡȭ\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=SOCK2_PORT size='6' value='9988'>";
   }
else{
   echo "<INPUT type='text' NAME=SOCK2_PORT size='6' value='$SOCK2_PORT'>";
   }
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ե\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=BAT_FILE size='80' value='/usr/local/zither/tmp/sitar.bat'>";
   }
else{
   echo "<INPUT type='text' NAME=BAT_FILE size='80' value='$BAT_FILE'>";
   }
echo "</td></tr>";

echo "<tr><td>";
echo "ե\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=BAT2_FILE size='80' value='/usr/local/zither/tmp/sitar.list'>";
   }
else{
   echo "<INPUT type='text' NAME=BAT2_FILE size='80' value='$BAT2_FILE'>";
   }
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ޥɤ֤\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=COMMAND_PATH size='80' value='/usr/local/zither/sample_bin'>";
   }
else{
   echo "<INPUT type='text' NAME=COMMAND_PATH size='80' value='$COMMAND_PATH'>";
   }
echo "</td></tr>";

echo "<tr><td>";
echo "ƻ륤󥿡Х뭡\n";
echo "</td><td>";
echo "<select size=1 name=BAT_INT>";
if(0 == strlen($CNAME)){ 
   echo "<option value=$BAT_INT selected>$BAT_INT";
   }
else{
   echo "<option value=60 selected>60";
   }
echo "<option value=60>60";
echo "<option value=30>30";
echo "<option value=60>60";
echo "<option value=90>90";
echo "<option value=120>120";
echo "<option value=150>150";
echo "<option value=180>180";
echo "<option value=210>210";
echo "<option value=240>240";
echo "</select>";
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "ƻ륤󥿡Х\n";
echo "</td><td>";
echo "<select size=1 name=BAT2_INT>";
if(0 == strlen($CNAME)){ 
   echo "<option value=$BAT2_INT selected>$BAT2_INT";
   }
else{
   echo "<option value=60 selected>60";
   }
echo "<option value=30>30";
echo "<option value=60>60";
echo "<option value=90>90";
echo "<option value=120>120";
echo "<option value=150>150";
echo "<option value=180>180";
echo "<option value=210>210";
echo "<option value=240>240";
echo "</select>";
echo "</td></tr>";

echo "<tr><td>";
echo "̴ƻ륤󥿡Х\n";
echo "</td><td>";
echo "<select size=1 name=LIFE_INT>";
if(0 == strlen($CNAME)){ 
   echo "<option value=$LIFE_INT selected>$LIFE_INT";
   }
else{
   echo "<option value=20 selected>20";
   }
echo "<option value=10>10";
echo "<option value=15>15";
echo "<option value=20>20";
echo "<option value=25>25";
echo "<option value=30>30";
echo "</select>";
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "̴ƻ\n";
echo "</td><td>";
echo "<select size=1 name=LIFE_LOS>";
if(0 == strlen($CNAME)){ 
   echo "<option value=$LIFE_LOS selected>$LIFE_LOS";
   }
else{
   echo "<option value=5 selected>5";
   }
echo "<option value=1>1";
echo "<option value=2>2";
echo "<option value=3>3";
echo "<option value=4>4";
echo "<option value=5>5";
echo "<option value=6>6";
echo "<option value=7>7";
echo "<option value=8>8";
echo "</select>";
echo "</td></tr>";

echo "<tr><td>";
echo "ᤤCC\n";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=MAIL_CC size='60' value='$MAIL_CC'>";
   }
else{
   echo "<INPUT type='text' NAME=MAIL_CC size='60' value=''>";
   }
echo "</td></tr>";

echo "<tr bgcolor='#D9DBED'><td>";
echo "UPDATEѥޥɤΥѥ";
echo "</td><td>";
if(0 == strlen($CNAME)){ 
   echo "<INPUT type='text' NAME=UPDATE_COM size='100' value='/usr/local/zither/bin/get_sitar.sh'>";
   }
else{
   echo "<INPUT type='text' NAME=UPDATE_COM size='100' value='$UPDATE_COM'>";
   }
echo "</td></tr>";

echo "<tr><td>";
echo "ܴƻɲ";
echo "</td><td>";
echo "<INPUT type='checkbox' value='ON' NAME=COM_MONITOR checked>";
echo "ʥ饤̾_defaultˤƺޤ";
echo "</td></tr>";

echo"</table>";

echo "\n";
echo "<font color=red>";
print("ǡ١ƤȿǤƱzitherФˤȿǤޤ\n");
print("ФȿǤ줿ϡưǴƻ륯饤ȤƵưޤΤդƤ\n");
echo "</font>";
echo "<input type=submit value='ƻ륯饤Ȥκ'>";
echo "</form>";




print("</font>");

?>

</pre>
</body>
</html>
